@@ -6,7 +6,7 @@
 #
 # LLNL-CODE-797170
 # All rights reserved.
-# This file is part of Merlin, Version: 1.5.3.
+# This file is part of Merlin, Version: 1.6.1.
 #
 # For details, see https://github.com/LLNL/merlin.
 #
@@ -320,7 +320,6 @@ class MerlinStudy:
             shutil.rmtree(workspace)
         os.mkdir(workspace)
 
-        LOG.info(f"Study workspace is '{workspace}'.")
         return workspace
 
     @cached_property
@@ -349,10 +348,45 @@ class MerlinStudy:
         if self.restart_dir is None:
             self.write_expanded_spec(self.expanded_filepath)
 
-        return MerlinSpec.load_specification(
+        result = MerlinSpec.load_specification(
             self.expanded_filepath, suppress_warning=False
         )
 
+        # expand provenance spec filename
+        if "$(" in self.spec.name:
+            expanded_name = result.description["name"].replace(" ", "_") + ".yaml"
+            expanded_workspace = os.path.join(
+                self.output_path,
+                f"{result.description['name'].replace(' ', '_')}_{self.timestamp}",
+            )
+            shutil.move(
+                self.expanded_filepath,
+                os.path.join(os.path.dirname(self.expanded_filepath), expanded_name),
+            )
+            shutil.move(self.workspace, expanded_workspace)
+
+            sample_file = result.merlin["samples"]["file"]
+            if sample_file.startswith(self.workspace):
+                new_samples_file = sample_file.replace(
+                    self.workspace, expanded_workspace
+                )
+                result.merlin["samples"]["generate"]["cmd"] = result.merlin["samples"][
+                    "generate"
+                ]["cmd"].replace(self.workspace, expanded_workspace)
+                result.merlin["samples"]["file"] = new_samples_file
+            self.workspace = expanded_workspace
+            self.info = os.path.join(self.workspace, "merlin_info")
+            self.special_vars["MERLIN_INFO"] = self.info
+            self.expanded_filepath = os.path.join(self.info, expanded_name)
+            result.path = self.expanded_filepath
+            self.spec.path = self.expanded_filepath
+            # rewrite provenance spec to correct samples.generate.cmd and samples.file
+            if self.restart_dir is None:
+                self.write_expanded_spec(self.expanded_filepath)
+
+        LOG.info(f"Study workspace is '{self.workspace}'.")
+        return result
+
     @cached_property
     def flux_command(self):
         """
